==> haskell-snap-server-1.1.1.2-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-snap-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 snap-server
version:              1.1.1.2
visibility:           public
id:                   snap-server-1.1.1.2-CQ12zI8HHVLTrTBZNWnDn
key:                  snap-server-1.1.1.2-CQ12zI8HHVLTrTBZNWnDn
license:              BSD-3-Clause
maintainer:           snap@snapframework.com
author:               Snap Framework Authors  (see CONTRIBUTORS)
homepage:             http://snapframework.com/
synopsis:             A web server for the Snap Framework
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.

    The Snap HTTP server is a high performance web server library written in
    Haskell. Together with the @snap-core@ library upon which it depends, it
    provides a clean and efficient Haskell programming interface to the HTTP
    protocol.

category:             Web, Snap, IO-Streams
abi:                  0da3031ce388aefefb108b5ac4caa85b
exposed:              True
exposed-modules:
    Snap.Http.Server Snap.Http.Server.Config Snap.Http.Server.Types
    Snap.Internal.Http.Server.Config Snap.Internal.Http.Server.Types
    System.FastLogger

hidden-modules:
    Paths_snap_server Control.Concurrent.Extended
    Snap.Internal.Http.Server.Address Snap.Internal.Http.Server.Clock
    Snap.Internal.Http.Server.Common Snap.Internal.Http.Server.Date
    Snap.Internal.Http.Server.Parser Snap.Internal.Http.Server.Session
    Snap.Internal.Http.Server.Socket Snap.Internal.Http.Server.Thread
    Snap.Internal.Http.Server.TimeoutManager
    Snap.Internal.Http.Server.TLS System.SendFile System.SendFile.Linux

import-dirs:          /usr/lib/ghc-8.10.1/site-local/snap-server-1.1.1.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/snap-server-1.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/snap-server-1.1.1.2
hs-libraries:         HSsnap-server-1.1.1.2-CQ12zI8HHVLTrTBZNWnDn
depends:
    attoparsec-0.13.2.4-GOTdzZbG0wqBeikq1tq7Wl base-4.14.0.0
    blaze-builder-0.4.1.0-2R9yQhqQRKlArR2rpVisZG bytestring-0.10.10.0
    case-insensitive-1.2.1.0-8AZUbBQpbxTCPQBw8ziEWX
    clock-0.8-4yRBAqo2RabIrS8VkLzaI9 containers-0.6.2.1
    filepath-1.4.2.1 io-streams-1.5.1.0-4MdWDVV6BeQJmcS4iq7w8w
    io-streams-haproxy-1.0.1.0-HyLQmxLKT4cI4552iQqtqF
    lifted-base-0.2.3.12-FPiBCT5Hs7W933gabtXvcP mtl-2.2.2
    network-3.1.1.1-D3CIp0WkhfC51dOZjHWRWc
    old-locale-1.0.0.7-He1fhgasqBf2zFT9zlaLle
    snap-core-1.0.4.1-1NZOJCPzMEzBgK3A8vGeEf text-1.2.3.2 time-1.9.3
    unix-2.7.2.2 unix-compat-0.5.2-LUrHZKGZjHj4senyv026n5
    vector-0.12.1.2-2820kU4E8Rq2FpOG9Xf2aE

haddock-interfaces:   /usr/share/doc/haskell-snap-server/html/snap-server.haddock
haddock-html:         /usr/share/doc/haskell-snap-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-snap-server-1.1.1.2-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-snap-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 snap-server
version:              1.1.1.2
visibility:           public
id:                   snap-server-1.1.1.2-H6ctIt5cf0x4xIcbGQMJI9
key:                  snap-server-1.1.1.2-H6ctIt5cf0x4xIcbGQMJI9
license:              BSD-3-Clause
maintainer:           snap@snapframework.com
author:               Snap Framework Authors  (see CONTRIBUTORS)
homepage:             http://snapframework.com/
synopsis:             A web server for the Snap Framework
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.

    The Snap HTTP server is a high performance web server library written in
    Haskell. Together with the @snap-core@ library upon which it depends, it
    provides a clean and efficient Haskell programming interface to the HTTP
    protocol.

category:             Web, Snap, IO-Streams
abi:                  685bf6b5b03a85e9eebd4dd08b19ad62
exposed:              True
exposed-modules:
    Snap.Http.Server Snap.Http.Server.Config Snap.Http.Server.Types
    Snap.Internal.Http.Server.Config Snap.Internal.Http.Server.Types
    System.FastLogger

hidden-modules:
    Paths_snap_server Control.Concurrent.Extended
    Snap.Internal.Http.Server.Address Snap.Internal.Http.Server.Clock
    Snap.Internal.Http.Server.Common Snap.Internal.Http.Server.Date
    Snap.Internal.Http.Server.Parser Snap.Internal.Http.Server.Session
    Snap.Internal.Http.Server.Socket Snap.Internal.Http.Server.Thread
    Snap.Internal.Http.Server.TimeoutManager
    Snap.Internal.Http.Server.TLS System.SendFile System.SendFile.Linux

import-dirs:          /usr/lib/ghc-8.10.1/site-local/snap-server-1.1.1.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/snap-server-1.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/snap-server-1.1.1.2
hs-libraries:         HSsnap-server-1.1.1.2-H6ctIt5cf0x4xIcbGQMJI9
depends:
    attoparsec-0.13.2.4-GOTdzZbG0wqBeikq1tq7Wl base-4.14.0.0
    blaze-builder-0.4.1.0-2R9yQhqQRKlArR2rpVisZG bytestring-0.10.10.0
    case-insensitive-1.2.1.0-8AZUbBQpbxTCPQBw8ziEWX
    clock-0.8-4yRBAqo2RabIrS8VkLzaI9 containers-0.6.2.1
    filepath-1.4.2.1 io-streams-1.5.1.0-4MdWDVV6BeQJmcS4iq7w8w
    io-streams-haproxy-1.0.1.0-HyLQmxLKT4cI4552iQqtqF
    lifted-base-0.2.3.12-FPiBCT5Hs7W933gabtXvcP mtl-2.2.2
    network-3.1.1.1-D3CIp0WkhfC51dOZjHWRWc
    old-locale-1.0.0.7-He1fhgasqBf2zFT9zlaLle
    snap-core-1.0.4.1-6oeb7ae7nop17kIF4e2iF2 text-1.2.3.2 time-1.9.3
    unix-2.7.2.2 unix-compat-0.5.2-LUrHZKGZjHj4senyv026n5
    vector-0.12.1.2-2820kU4E8Rq2FpOG9Xf2aE

haddock-interfaces:   /usr/share/doc/haskell-snap-server/html/snap-server.haddock
haddock-html:         /usr/share/doc/haskell-snap-server/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
